#
# spec file for package python3-feedparser
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-feedparser
Version:        5.2.1
Release:        7.1
Summary:        Universal Feed Parser Module for Python
License:        BSD-2-Clause
Group:          Development/Libraries/Python
Url:            https://github.com/kurtmckee/feedparser
Source:         https://pypi.python.org/packages/source/f/feedparser/feedparser-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3
BuildRequires:  python3-2to3
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-xml
Requires:       python3-xml
BuildArch:      noarch

%description
A universal feed parser module for Python that handles RSS 0.9x, RSS 1.0, RSS
2.0, CDF, Atom 0.3, Atom 1.0 feeds.

%prep
%setup -q -n feedparser-%{version}
find . -type f -exec chmod 0644 {} \;  # 5.2.1 had executable bit set on almost all files

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root)
%doc LICENSE NEWS README.rst
%{python3_sitelib}/*

%changelog
* Sun Aug  9 2015 arun@gmx.de
- update to version 5.2.1:
  * Fix #22 (pip package keeps upgrading all the time)
* Sun Apr 19 2015 arun@gmx.de
- specfile:
  * update copyright year
  * update url
  * added pypi source url
  * README -> README.rst
  * require setuptools
- update to version 5.2.0:
  * Support PyPy
  * Remove the HTTP Status 9001 test that caused unit test tracebacks
  * Remove the completely-untested HTML tidy code
  * Remove BeautifulSoup as a dependency
  * Remove the XFN microformat parsing code
  * Remove the rel_enclosure microformat parsing code
  * Remove the rel_hcard microformat parsing code
  * Remove the rel_tag microformat parsing code
  * Replace the regex-based RFC 822 date parser with a procedural one
  * Replace the Python-licensed W3DTF date parser
  * Support HTML5 audio/source/video element relative URL's
  * Remove the unparsed itunes_keywords key from the result dictionary
  * Fix issue 321 just a little more (yet another code path was missed)
  * Issue 62 (support georss and gml namespaces)
  * Issue 296 (GUID's are always treated like relative URI's)
  * Issue 334 (media:restriction element content is not returned)
  * Issue 335 (sub-elements of media:group are not parsed and returned)
  * Issue 342 (support multiple dc:creator elements)
  * Issue 357 (loose parser breaks ampersands in link element URL's)
  * Issue 374 (support the Podlove Simple Chapters namespace)
  * Issue 380 (support media:rating element)
  * Issue 384 (fix chardet support in Python 3)
  * Issue 389 (elements in unknown uppercase namespaces are ignored)
  * Issue 392 (tags element subverts 'tags' key in result dictionary)
  * Issue 396 (Podlove Simple Chapters version 1.0 causes a KeyError)
  * Issue 399 (docs call `request_headers` parameter `extra_headers`)
  * Issue 401 (support additional dcterms and media namespaces elements)
  * Issue 404 (support asctime datetime strings with timezone information)
  * Issue 407 (decode forward slashes encoded as character entities)
  * Issue 421 (delay chardet invocation as long as possible)
  * Issue 422 (add return types docstrings)
  * Issue 433 (update the list of allowed MathML elements and attributes)
* Sun Mar  3 2013 arun@gmx.de
- Update to 5.1.3 (taken from google code webpage:
  * feedparser 5.1.3 (December 9, 2012)
  * Consolidated and simplified the character encoding detection code
  * Issue 346  (the gb2312 encoding isn't always upgraded to gb18030)
  * Issue 350  (HTTP Last-Modified example is incorrect in documentation)
  * Issue 352  (importing lxml.etree changes what exceptions libxml2 throws)
  * Issue 356  (add support for the HTML5 attributes poster and preload)
  * Issue 364  (enclosure-sniffing microformat code can throw ValueError)
  * Issue 373  (support RFC822-ish dates with swapped days and months)
  * Issue 376  (uppercase 'X' in hex character references cause ValueError)
  * Issue 382  (don't strip inline user:password credentials from FTP URL's)
* Sat Jun  9 2012 os-dev@jacraig.com
- Update to 5.1.2:
  * Minor changes to the documentation
  * Strip potentially dangerous ENTITY declarations in encoded feeds
  * feedparser will now try to continue parsing despite compression errors
  * Fix issue 321 a little more (the initial fix missed a code path)
  * Issue 337 (`_parse_date_rfc822()` returns None on single-digit days)
  * Issue 343 (add magnet links to the ACCEPTABLE_URI_SCHEMES)
  * Issue 344 (handle deflated data with no headers nor checksums)
  * Issue 347 (support `itunes:image` elements with a `url` attribute)
- Remove now-unneeded chmod of README
* Tue Mar 20 2012 jfunk@funktronics.ca
- Update to 5.1.1:
  * Fix mistakes, typos, and bugs in the unit test code
  * Fix crash in Python 2.4 and 2.5 if the feed has a UTF_32 byte order mark
  * Replace the RFC822 date parser for more extensibility
  * Issue 304  (handle RFC822 dates with timezones like GMT+00:00)
  * Issue 309  (itunes:keywords should be split by commas, not whitespace)
  * Issue 310  (pubDate should map to published, not updated)
  * Issue 313  (include the compression test files in MANIFEST.in)
  * Issue 314  (far-flung RFC822 dates don't throw OverflowError on x64)
  * Issue 315  (HTTP server for unit tests runs on 0.0.0.0)
  * Issue 321  (malformed URIs can cause ValueError to be thrown)
  * Issue 322  (HTTP redirect to HTTP 304 causes SAXParseException)
  * Issue 323  (installing chardet causes 11 unit test failures)
  * Issue 325  (map description_detail to summary_detail)
  * Issue 326  (Unicode filename causes UnicodeEncodeError if locale is ASCII)
  * Issue 327  (handle RFC822 dates with extraneous commas)
  * Issue 328  (temporarily map updated to published due to  issue 310 )
  * Issue 329  (escape backslashes in Windows path in docs/introduction.rst)
  * Issue 331  (don't escape backslashes that are in raw strings in the docs)
- Re-enabled tests now that the broken ones are fixed
* Tue Feb 21 2012 saschpe@suse.de
- Fix feedparser.py syntax error
* Sun Feb 19 2012 saschpe@gmx.de
- Remove outdated %%clean section, no CFLAGS for noarch package
* Thu Jan 12 2012 jfunk@funktronics.ca
- Temporarily disabled tests due to false failures. Should be re-enabled in
  5.1.1
- Update to 5.1:
  * Extensive, extensive unit test refactoring
  * Convert the Docbook documentation to ReST
  * Include the documentation in the source distribution
  * Consolidate the disparate README files into one
  * Support Jython somewhat (almost all unit tests pass)
  * Support Python 3.2
  * Fix Python 3 issues exposed by improved unit tests
  * Fix international domain name issues exposed by improved unit tests
  * Issue 148 (loose parser doesn't always return unicode strings)
  * Issue 204 (FeedParserDict behavior should not be controlled by `assert`)
  * Issue 247 (mssql date parser uses hardcoded tokyo timezone)
  * Issue 249 (KeyboardInterrupt and SystemExit exceptions being caught)
  * Issue 250 (`updated` can be a 9-tuple or a string, depending on context)
  * Issue 252 (running setup.py in Python 3 fails due to missing sgmllib)
  * Issue 253 (document that text/plain content isn't sanitized)
  * Issue 260 (Python 3 doesn't decompress gzip'ed or deflate'd content)
  * Issue 261 (popping from empty tag list)
  * Issue 262 (docs are missing from distribution files)
  * Issue 264 (vcard parser crashes on non-ascii characters)
  * Issue 265 (http header comparisons are case sensitive)
  * Issue 271 (monkey-patching sgmllib breaks other libraries)
  * Issue 272 (can't pass bytes or str to `parse()` in Python 3)
  * Issue 275 (`_parse_date()` doesn't catch OverflowError)
  * Issue 276 (mutable types used as default values in `parse()`)
  * Issue 277 (`python3 setup.py install` fails)
  * Issue 281 (`_parse_date()` doesn't catch ValueError)
  * Issue 282 (`_parse_date()` crashes when passed `None`)
  * Issue 285 (crash on empty xmlns attribute)
  * Issue 286 ('apos' character entity not handled properly)
  * Issue 289 (add an option to disable microformat parsing)
  * Issue 290 (Blogger's invalid img tags are unparseable)
  * Issue 292 (atom id element not explicitly supported)
  * Issue 294 ('categories' key exists but raises KeyError)
  * Issue 297 (unresolvable external doctype causes crash)
  * Issue 298 (nested nodes clobber actual values)
  * Issue 300 (performance improvements)
  * Issue 303 (unicode characters cause crash during relative uri resolution)
  * Remove "Hot RSS" support since the format doesn't actually exist
  * Remove the old feedparser.org website files from the source
  * Remove the feedparser command line interface
  * Remove the Zope interoperability hack
  * Remove extraneous whitespace
* Thu Dec  8 2011 coolo@suse.com
- fix license to be in spdx.org format
* Thu Jun  9 2011 saschpe@suse.de
- * Moved chmod 0644 README back to %%prep section
* Tue May 31 2011 saschpe@suse.de
- Spec file cleanup:
  * Moved unittests to %%check section
  * Removed authors from description
  * Don't test on SLES_9, fixes build
* Mon May 30 2011 jfunk@funktronics.ca
- Update to 5.0.1
  - Fix issue 91 (invalid text in XML declaration causes sanitizer to crash)
  - Fix issue 254 (sanitization can be bypassed by malformed XML comments)
  - Fix issue 255 (sanitizer doesn't strip unsafe URI schemes)
- Previous release: 5.0 - January 25, 2011
  - Improved MathML support
  - Support microformats (rel-tag, rel-enclosure, xfn, hcard)
  - Support IRIs
  - Allow safe CSS through sanitization
  - Allow safe HTML5 through sanitization
  - Support SVG
  - Support inline XML entity declarations
  - Support unescaped quotes and angle brackets in attributes
  - Support additional date formats
  - Added the request_headers argument to parse()
  - Added the response_headers argument to parse()
  - Support multiple entry, feed, and source authors
  - Officially make Python 2.4 the earliest supported version
  - Support Python 3
  - Bug fixes, bug fixes, bug fixes
* Thu Sep  3 2009 matejcik@suse.cz
- build as noarch
- import from OBS, original changelog follows:
* Sun Feb 15 2009 James Oakley <jfunk@funktronics.ca> - 4.1-1
- initial release
